@@ -750,6 +750,7 @@ bool DataSet::loadObjects(const char *file_name, bool is_user_defs) {
 				}
 				child = child->next;
 			}
+			if(is_user_defs) o->setUserModified(true);
 			if(!old_object) objects.push_back(o);
 		}
 		cur = cur->next;
@@ -762,6 +763,7 @@ bool DataSet::loadObjects(const char *file_name, bool is_user_defs) {
 	return true;
 }
 int DataSet::saveObjects(const char *file_name, bool save_global) {
+	if(!b_loaded) return 1;
 	string str, filename;
 	if(!save_global && !file_name) {
 		recursiveMakeDir(getLocalDataDir());
@@ -839,6 +841,8 @@ int DataSet::saveObjects(const char *file_name, bool save_global) {
 	int returnvalue = 1;
 	if(do_save) {
 		returnvalue = xmlSaveFormatFile(filename.c_str(), doc, 1);
+	} else {
+		if(fileExists(filename)) remove(filename.c_str());
 	}
 	xmlFreeDoc(doc);
 	return returnvalue;
@@ -903,7 +907,9 @@ const string &DataSet::getNextPropertyName(DataPropertyIter *it) {
 }
 
 void DataSet::addObject(DataObject *o) {
+	if(!objectsLoaded()) loadObjects();
 	objects.push_back(o);
+	b_loaded = true;
 }
 void DataSet::delObject(DataObject *o) {
 	for(size_t i = 0; i < objects.size(); i++) {
